package com.kmall.schedule.dao;

import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @author huangyq
 * @date 2019/5/5.
 */
@Component
public interface QzStoreTicketDiscountMapper {

    /**
     * 查询时间类型为固定时间的优惠券数据
     *
     * @return
     */
    List<Map> queryStoreTicketDiscountListBy00();
    /**
     * 查询时间类型为领取后的优惠券数据
     *
     * @return
     */
    List<Map> queryStoreTicketDiscountListBy01();

    /**
     * 查询库存为0的优惠券数据
     *
     * @return
     */
    List<Map> queryStoreTicketDiscountListByLimit();

    /**
     * 更新过期状态
     *
     * @param fromObject
     */
    void updateStoreTicketDiscount(Map fromObject);

    /**
     * 更新用户领取优惠券已过期
     * @param fromObject
     */
    void updateUserCoupon(Map fromObject);

    Map selectAdIdByDiscId(@Param("tickDiscId") Integer tickDiscId);

    /**
     * 将失效优惠券广告位设置为失效
     * @param fromObject
     */
    void updateAd(Map fromObject);

    void updateStoreTopic(@Param("storeTopicId")Integer storeTopicId);
}
